/*******************************************************************
 *                  Light Weight Chord Library 1.0                 *
 *  CopyRight(C) Yoshihide Matsumoto IDEON WorkingGroup 2003,2004  *
 *      matsumoto333@yahoo.co.jp (http://www.matchan.mydns.jp)     *
 *                                                                 *
 * Implementation of chord (Distributed Hash Table)                *
 * This program is distributed under GPL                           *
 * Light Weight Chord Library comes with ABSOLUTELY NO WARRANTY.   *
 * This is free software, and you are welcome to redistribute it   *
 * under certain conditions; read `COPYING' for details.           *
 *******************************************************************/


#ifndef __RECVLIST
#define __RECVLIST

typedef struct _RECVLIST {

  int sess_id;
  int count;
  int action;
  void(*func)(int);
  
  struct _RECVLIST *prev;
  struct _RECVLIST *next;
}RECVLIST;

#endif

RECVLIST *recv_insert(RECVLIST **phead, int sess_id, int action, 
		      void(*func)(int));
RECVLIST *recv_delete_key(RECVLIST **phead, int sess_id);
RECVLIST *recv_delete(RECVLIST **phead, RECVLIST *pdel);


RECVLIST *recv_search(RECVLIST *plist, int sess_id);
int  recv_size(RECVLIST *plist);
void recv_print(RECVLIST **plist);



